use axum::{routing::get, Router};

mod constants;
mod context;
pub mod prelude;
mod registry;
pub mod repository;
pub mod state;
pub mod views;
pub mod widgets;

use state::DepotFn;

pub fn routes<S: DepotFn>() -> Router<S> {
    Router::new()
        .route("/", get(views::index::<S>).post(views::index_action::<S>))
        .route("/:section", get(views::list_section::<S>))
        .route(
            "/:section/model/:model",
            get(views::list_item_collection::<S>),
        )
        .route(
            "/:section/model/:model/add",
            get(views::new_item::<S>).post(views::create_item::<S>),
        )
        .route(
            "/:section/model/:model/change/:id",
            get(views::change_item::<S>).patch(views::update_item::<S>),
        )
        .route(
            "/:section/model/:model/detail/:id",
            get(views::view_item_details::<S>),
        )
}
